@@ -4,6 +4,7 @@ import numpy as np
 import itertools as it
 import pandas as pd
 import tables
+import pprint 
 import time as sys_time
 from numba import njit
 from copy import deepcopy
@@ -550,6 +551,12 @@ def get_hmm_spike_data(rec_dir, unit_type, channel, time_start=None,
         units = unit_type
 
     time, spike_array = h5io.get_spike_data(rec_dir, units, channel, trials=trials)
+    
+    if isinstance(channel, list):
+        to_cat = [spike_array[key] for key in spike_array.keys()]
+        spike_array = np.concatenate(to_cat, axis = 0)
+        
+    
     spike_array = spike_array.astype(np.int32)
     if len(units) == 1:
         spike_array = np.expand_dims(spike_array, 1)
@@ -1312,9 +1319,9 @@ class HmmHandler(object):
 
         #self.plot_saved_models()
         self.load_params()
-
-    def plot_saved_models(self):
-        print('Plotting saved models')
+        
+    def plot_spike_rasters(self):
+        print('Plotting just rasters')
         data = self.get_data_overview().set_index('hmm_id')
         rec_dir = self.root_dir
         for i, row in data.iterrows():
@@ -1324,6 +1331,34 @@ class HmmHandler(object):
             else:
                 trials = params['n_trials']
 
+            spikes, dt, time = get_hmm_spike_data(rec_dir, params['unit_type'],
+                                                  params['channel'],
+                                                  time_start=params['time_start'],
+                                                  time_end=params['time_end'],
+                                                  dt=params['dt'],
+                                                  trials=trials,
+                                                  area=params['area'])
+            plot_dir = os.path.join(self.plot_dir, 'hmm_%s' % i)
+            if not os.path.isdir(plot_dir):
+                os.makedirs(plot_dir)
+
+            save_file = os.path.join(plot_dir, 'trial_raster')
+            print('Plotting HMM %s...' % i)
+            hmmplt.make_hmm_raster(spikes,time, save_file)
+
+    def plot_saved_models(self):
+        print('Plotting saved models')
+        data = self.get_data_overview().set_index('hmm_id')
+        rec_dir = self.root_dir
+        for i, row in data.iterrows():
+            
+            hmm, _, params = load_hmm_from_hdf5(self.h5_file, i)
+            if params.get('trial_nums') is not None:
+                trials = params['trial_nums']
+            else:
+                trials = params['n_trials']
+                
+
             spikes, dt, time = get_hmm_spike_data(rec_dir, params['unit_type'],
                                                   params['channel'],
                                                   time_start=params['time_start'],
