@@ -1,8 +1,12 @@
 import os
 import pandas as pd
-from blechpy.datastructures.objects import data_object, load_experiment
+from blechpy.datastructures.objects import data_object, load_experiment, load_dataset
+from blechpy.utils import write_tools as wt
 from blechpy.utils.decorators import Logger
 from blechpy.utils import userIO
+from blechpy.analysis import poissonHMM as phmm
+from joblib import Parallel, delayed
+#import glob
 
 class project(data_object):
 
@@ -35,7 +39,8 @@ class project(data_object):
         self._exp_info = pd.DataFrame({'exp_name': exp_names,
                                        'exp_group': exp_groups,
                                        'exp_dir': exp_dirs})
-        self.rec_info= self.get_rec_info(self)
+        
+        self.rec_info= self.get_rec_info()
 
         # Make list of all major files managed by this object
         self._files = {'params':
@@ -128,6 +133,23 @@ class project(data_object):
         self.rec_info = self.get_rec_info()
         self.save()
         
+    def get_trial_info(self):
+        dflist = []
+        rec_info = self.get_rec_info()
+        
+        for i, row in rec_info.iterrows():
+            rd = row['rec_dir']
+            dat = load_dataset(rd)
+            dit = dat.dig_in_trials
+            dit['taste_trial'] = True
+            dit['taste_trial'] = dit.groupby(['channel']).taste_trial.cumsum()
+            dit['rec_dir'] = rd
+            dflist.append(dit)
+        outdf = pd.concat(dflist)
+        outdf= outdf.rename(columns = {'trial':'session_trial'})
+        
+        return(outdf)
+        
     def get_rec_info(self): 
         rec_info = pd.DataFrame(columns=['exp_name',
                                          'rec_name',
@@ -157,4 +179,46 @@ class project(data_object):
                     print('error: session number not in experiment ', rec_name)
                 
         return rec_info
+    
+    def change_rec_roots(self):
+        rec_info = self.rec_info
+        for i, row in rec_info.iterrows():
+            dat = load_dataset(row['rec_dir'])
+            dat._change_root(row['rec_dir'])
+            dat.save()
         
+    def make_raster_plots(self):
+        rec_info = self.rec_info
+        for i, row in rec_info.iterrows():
+            dat = load_dataset(row['rec_dir'])
+            dat.make_raster_plots()
+    
+    def make_ensemble_raster_plots(self):
+        rec_info = self.rec_info
+        for i, row in rec_info.iterrows():
+            dat = load_dataset(row['rec_dir'])
+            dat.make_ensemble_raster_plots()
+            
+    #idk if this would actually work, I will need to figure this one out
+    def apply_dat_function(self, function):
+        rec_info = self.rec_info
+        for i, row in rec_info.iterrows():
+            dat = load_dataset(row['rec_dir'])
+            dat.function()
+            
+    def plot_hmms(self):
+        '''
+        Plots hmms under each recording analysis directory in your project. Requires that you have already run HMMs
+
+        '''
+        rec_info = self.get_rec_info()
+        rec_dirs = rec_info.rec_dir
+
+        def load_plot_hmm(rec_dir):
+            handler = phmm.HmmHandler(rec_dir)
+            handler.plot_saved_models()
+            
+        n_cpu = os.cpu_count()
+            
+        Parallel(n_jobs = n_cpu-1)(delayed(load_plot_hmm)(i) for i in rec_dirs)
+            
\ No newline at end of file
